import{u as S,V as d,a as i,m as A,b as R}from"./VInput-C_1AW61Q.js";import{B as U,C as z,a1 as D,r as E,c2 as G,G as H,c3 as J,b as m,aB as b,aJ as M,T,d as $,c as t,o as n,F as j,e as f,H as y,a as o}from"./index-Bn2Tzsay.js";const q=z({...A(),...T(R(),["inline"])},"VCheckbox"),O=U()({name:"VCheckbox",inheritAttrs:!1,props:q(),emits:{"update:modelValue":e=>!0,"update:focused":e=>!0},setup(e,r){let{attrs:a,slots:u}=r;const s=D(e,"modelValue"),{isFocused:p,focus:V,blur:v}=S(e),c=E(),k=G();return H(()=>{const[g,h]=J(a),B=d.filterProps(e),x=i.filterProps(e);return m(d,b({ref:c,class:["v-checkbox",e.class]},g,B,{modelValue:s.value,"onUpdate:modelValue":l=>s.value=l,id:e.id||`checkbox-${k}`,focused:p.value,style:e.style}),{...u,default:l=>{let{id:w,messagesId:C,isDisabled:P,isReadonly:I,isValid:F}=l;return m(i,b(x,{id:w.value,"aria-describedby":C.value,disabled:P.value,readonly:I.value},h,{error:F.value===!1,modelValue:s.value,"onUpdate:modelValue":N=>s.value=N,onFocus:V,onBlur:v}),u)}})}),M({},c)}}),Q=$({__name:"NowPlayingBadge",props:{showBadge:{type:Boolean,default:!0},showIcon:{type:Boolean,default:!0},badgeStyle:{default:""},iconStyle:{default:""}},setup(e){return(r,a)=>(n(),t(j,null,[e.showBadge?(n(),t("span",{key:0,style:y(e.badgeStyle),class:"now-playing-badge","aria-label":"Now playing"}," Now playing ",4)):f("",!0),e.showIcon?(n(),t("div",{key:1,style:y(e.iconStyle),class:"now-playing-icon"},[...a[0]||(a[0]=[o("div",{class:"bar"},null,-1),o("div",{class:"bar"},null,-1),o("div",{class:"bar"},null,-1),o("div",{class:"bar"},null,-1)])],4)):f("",!0)],64))}});export{O as V,Q as _};
