import{I as c}from"./ItemsListing-XUXN-Um6.js";import{I as f,_ as v}from"./ProviderDetails.vue_vue_type_script_setup_true_lang-Cn4WWbvY.js";import{d as h,r as y,ae as I,c as w,b as V,h as n,e as p,a as g,o as s,v as m,bE as k}from"./index-Bn2Tzsay.js";import"./Container-CEbFgC5b.js";import"./index-CBho6rsP.js";import"./VContainer-CRIwFZfO.js";/* empty css              */import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./Toolbar-Ba4dAxS1.js";import"./VToolbar-Z0nE2qFc.js";import"./VBtn-BQk37KYJ.js";import"./Button-r9Wpw3CQ.js";import"./ListItem-BNbxxrdg.js";import"./NowPlayingBadge.vue_vue_type_style_index_0_lang-DCLVCnPO.js";import"./VInput-C_1AW61Q.js";import"./MediaItemThumb-B7hfZSf2.js";import"./PanelviewItemCompact-By5cXXTW.js";import"./VSpacer-ygjaGObn.js";import"./VTextField-fPA0WAHx.js";import"./VInfiniteScroll-DvbiA0kw.js";import"./layout-kFqKNtL6.js";import"./VRow-CNVApy9v.js";import"./VVirtualScroll-B56qZ1Y0.js";import"./VAlert-Bj5fXNhB.js";import"./marquee_text_sync-CHIyYfjU.js";import"./VDialog-DRfRMr5_.js";const U=h({__name:"RadioDetails",props:{itemId:{},provider:{}},setup(a){const t=a,e=y(),l=async function(){e.value=await m.getRadio(t.itemId,t.provider)};I(()=>t.itemId,o=>{o&&l()},{immediate:!0});const d=async function(o){const i=[];if(t.provider=="library"){const r=await m.getRadioVersions(t.itemId,t.provider);i.push(...r)}for(const r of k(e.value)){const u=await m.getRadioVersions(r.item_id,r.provider_instance);i.push(...u)}return i};return(o,i)=>(s(),w("section",null,[V(f,{item:e.value},null,8,["item"]),e.value?(s(),n(c,{key:0,itemtype:"radioversions","parent-item":e.value,"show-provider":!0,"show-favorites-only-filter":!1,"show-library":!1,"show-radio-number":!1,"show-duration":!1,"load-items":d,"sort-keys":["provider","sort_name"],title:o.$t("other_versions"),"hide-on-empty":!0,checksum:a.provider+a.itemId},null,8,["parent-item","title","checksum"])):p("",!0),i[0]||(i[0]=g("br",null,null,-1)),e.value?(s(),n(v,{key:1,"item-details":e.value},null,8,["item-details"])):p("",!0)]))}});export{U as default};
