import{B as g,C as v,G as b,b as a,H as f,n as h,I as x,K as y,a as l,X as N,W as H,Z as I,a0 as R,Q as E,R as D,ad as w,O as m,a4 as z,S as G,a7 as q,a8 as F,aa as K,aG as O,aH as r,a5 as s,cq as Q}from"./index-Bn2Tzsay.js";const U=v({text:String,...y(),...x()},"VToolbarTitle"),W=g()({name:"VToolbarTitle",props:U(),setup(e,o){let{slots:t}=o;return b(()=>{const n=!!(t.default||t.text||e.text);return a(e.tag,{class:h(["v-toolbar-title",e.class]),style:f(e.style)},{default:()=>[n&&l("div",{class:"v-toolbar-title__placeholder"},[t.text?t.text():e.text,t.default?.()])]})}),{}}}),X=[null,"prominent","default","comfortable","compact"],Z=v({absolute:Boolean,collapse:Boolean,color:String,density:{type:String,default:"default",validator:e=>X.includes(e)},extended:{type:Boolean,default:null},extensionHeight:{type:[Number,String],default:48},flat:Boolean,floating:Boolean,height:{type:[Number,String],default:64},image:String,title:String,...K(),...y(),...F(),...q(),...x({tag:"header"}),...G()},"VToolbar"),j=g()({name:"VToolbar",props:Z(),setup(e,o){let{slots:t}=o;const{backgroundColorClasses:n,backgroundColorStyles:T}=N(()=>e.color),{borderClasses:V}=H(e),{elevationClasses:k}=I(e),{roundedClasses:C}=R(e),{themeClasses:_}=E(e),{rtlClasses:B}=D(),i=w(e.extended===null?!!t.extension?.():e.extended),d=m(()=>parseInt(Number(e.height)+(e.density==="prominent"?Number(e.height):0)-(e.density==="comfortable"?8:0)-(e.density==="compact"?16:0),10)),u=m(()=>i.value?parseInt(Number(e.extensionHeight)+(e.density==="prominent"?Number(e.extensionHeight):0)-(e.density==="comfortable"?4:0)-(e.density==="compact"?8:0),10):0);return z({VBtn:{variant:"text"}}),b(()=>{const S=!!(e.title||t.title),P=!!(t.image||e.image),c=t.extension?.();return i.value=e.extended===null?!!c:e.extended,a(e.tag,{class:h(["v-toolbar",{"v-toolbar--absolute":e.absolute,"v-toolbar--collapse":e.collapse,"v-toolbar--flat":e.flat,"v-toolbar--floating":e.floating,[`v-toolbar--density-${e.density}`]:!0},n.value,V.value,k.value,C.value,_.value,B.value,e.class]),style:f([T.value,e.style])},{default:()=>[P&&l("div",{key:"image",class:"v-toolbar__image"},[t.image?a(r,{key:"image-defaults",disabled:!e.image,defaults:{VImg:{cover:!0,src:e.image}}},t.image):a(O,{key:"image-img",cover:!0,src:e.image},null)]),a(r,{defaults:{VTabs:{height:s(d.value)}}},{default:()=>[l("div",{class:"v-toolbar__content",style:{height:s(d.value)}},[t.prepend&&l("div",{class:"v-toolbar__prepend"},[t.prepend?.()]),S&&a(W,{key:"title",text:e.title},{text:t.title}),t.default?.(),t.append&&l("div",{class:"v-toolbar__append"},[t.append?.()])])]}),a(r,{defaults:{VTabs:{height:s(u.value)}}},{default:()=>[a(Q,null,{default:()=>[i.value&&l("div",{class:"v-toolbar__extension",style:{height:s(u.value)}},[c])]})]})]})}),{contentHeight:d,extensionHeight:u}}});export{j as V,W as a};
