import{d as p,m as y,h as o,o as t,N as b,u as n,bv as k,w as a,aR as h,c as m,n as C,b as r,a as v,e as c,z as V,t as R,aX as B,bt as $,F as x,g as M,bw as A,M as g,b5 as I}from"./index-Bn2Tzsay.js";import{P as N}from"./PanelviewItemCompact-By5cXXTW.js";import{V as P}from"./VToolbar-Z0nE2qFc.js";import{V as u}from"./VBtn-BQk37KYJ.js";import{V as T}from"./VAlert-Bj5fXNhB.js";import{_ as z}from"./_plugin-vue_export-helper-DlAUqK2U.js";const O=p({__name:"Carousel",setup(e){return y(()=>{document.documentElement.style.setProperty("--swiper-navigation-color","primary")}),(d,l)=>{const w=b("swiper");return t(),o(w,{"slides-per-view":n(k)(d.$vuetify.display.width)+.5,"free-mode":!0,navigation:!1,mousewheel:{forceToAxis:!0,releaseOnEdges:!0}},{default:a(()=>[h(d.$slots,"default")]),_:3},8,["slides-per-view"])}}}),E={class:"mr-3"},W={key:0},D={class:"carousel-wrapper"},F=p({__name:"WidgetRow",props:{widgetRow:{},editMode:{type:Boolean},showProviderOnCover:{type:Boolean}},emits:["update:settings"],setup(e,{emit:d}){const l=d;return(w,s)=>{const f=b("swiper-slide");return t(),m("div",{class:C(`widget-row ${e.widgetRow.settings&&!e.widgetRow.settings.enabled?"disabled":""}`)},[r(P,{class:"header",color:"transparent"},{title:a(()=>[v("span",E,R(e.widgetRow.title),1),e.widgetRow.subtitle&&n(B)("bp6")?(t(),o($,{key:0,inline:"",outlined:"",text:e.widgetRow.subtitle,density:"compact",size:"small"},null,8,["text"])):c("",!0)]),append:a(()=>[e.editMode&&e.widgetRow.settings?(t(),m("div",W,[e.widgetRow.settings.position!==0?(t(),o(u,{key:0,icon:"mdi-chevron-up",class:"enabled",onClick:s[0]||(s[0]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position-1}))})):c("",!0),r(u,{icon:"mdi-chevron-down",onClick:s[1]||(s[1]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position+1}))}),r(u,{icon:e.widgetRow.settings.enabled?"mdi-checkbox-marked":"mdi-checkbox-blank-outline",onClick:s[2]||(s[2]=i=>l("update:settings",{...e.widgetRow.settings,enabled:!e.widgetRow.settings.enabled}))},null,8,["icon"])])):e.widgetRow.provider?(t(),o(V,{key:1,domain:e.widgetRow.provider,size:24},null,8,["domain"])):c("",!0)]),_:1}),v("div",D,[e.widgetRow.items.length>0?(t(),o(O,{key:0},{default:a(()=>[(t(!0),m(x,null,M(e.widgetRow.items,i=>(t(),o(f,{key:i.uri},{default:a(()=>[r(N,{item:i,"show-provider-on-cover":e.showProviderOnCover,"permanent-overlay":![n(g).ALBUM,n(g).TRACK,n(g).RADIO].includes(i.media_type),"is-available":n(A)(i),disabled:e.editMode},null,8,["item","show-provider-on-cover","permanent-overlay","is-available","disabled"])]),_:2},1024))),128))]),_:1})):(t(),o(T,{key:1},{default:a(()=>[I(R(w.$t("no_content")),1)]),_:1}))])],2)}}}),q=z(F,[["__scopeId","data-v-a88771f6"]]);export{q as W};
