.providers-header[data-v-0f69e320]{display:flex;align-items:stretch;justify-content:space-between;gap:16px;flex-wrap:wrap;padding:20px 20px 6px}.add-provider-btn[data-v-0f69e320]{flex-shrink:0;align-self:center}@media (max-width: 960px){.providers-header[data-v-0f69e320]{flex-direction:column;align-items:stretch}.add-provider-btn[data-v-0f69e320]{width:100%;align-self:stretch}}.provider-description[data-v-0f69e320]{display:-webkit-box;-webkit-line-clamp:3;line-clamp:3;-webkit-box-orient:vertical;overflow:hidden;text-overflow:ellipsis;line-height:1.4em;max-height:4.2em}.provider-description.truncated-text[data-v-0f69e320]{margin-bottom:16px!important}
