import{I as f,_ as v}from"./ProviderDetails.vue_vue_type_script_setup_true_lang-Cn4WWbvY.js";import{I}from"./ItemsListing-XUXN-Um6.js";import{d as _,r as m,ae as h,m as b,v as a,a$ as y,q as k,c as w,b as E,h as p,e as n,F as D,o as r}from"./index-Bn2Tzsay.js";import"./Toolbar-Ba4dAxS1.js";import"./VToolbar-Z0nE2qFc.js";import"./VBtn-BQk37KYJ.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./marquee_text_sync-CHIyYfjU.js";import"./MediaItemThumb-B7hfZSf2.js";import"./VDialog-DRfRMr5_.js";import"./layout-kFqKNtL6.js";import"./Container-CEbFgC5b.js";import"./index-CBho6rsP.js";import"./VContainer-CRIwFZfO.js";/* empty css              */import"./ListItem-BNbxxrdg.js";import"./Button-r9Wpw3CQ.js";import"./NowPlayingBadge.vue_vue_type_style_index_0_lang-DCLVCnPO.js";import"./VInput-C_1AW61Q.js";import"./PanelviewItemCompact-By5cXXTW.js";import"./VSpacer-ygjaGObn.js";import"./VTextField-fPA0WAHx.js";import"./VInfiniteScroll-DvbiA0kw.js";import"./VRow-CNVApy9v.js";import"./VVirtualScroll-B56qZ1Y0.js";import"./VAlert-Bj5fXNhB.js";const X=_({__name:"PodcastDetails",props:{itemId:{},provider:{}},setup(l){const t=l,i=m(!1),e=m(),d=async function(){e.value=await a.getPodcast(t.itemId,t.provider)};h(()=>t.itemId,o=>{o&&d()},{immediate:!0}),b(()=>{const o=a.subscribe(y.MEDIA_ITEM_UPDATED,s=>{const c=s.data;e.value?.uri==c.uri&&(i.value=!0)});k(o)});const u=async function(o){return await a.getPodcastEpisodes(t.itemId,t.provider)};return(o,s)=>(r(),w(D,null,[E(f,{item:e.value},null,8,["item"]),e.value?(r(),p(I,{key:0,itemtype:"podcastepisodes","parent-item":e.value,"show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!0,"show-refresh-button":!0,"load-items":u,"sort-keys":["position","position_desc","name","duration","duration_desc"],"update-available":i.value,title:o.$t("podcast_episodes"),"allow-key-hooks":!0,path:`podcast.${t.itemId}.${t.provider}`,"restore-state":!0,"no-server-side-sorting":!0},null,8,["parent-item","update-available","title","path"])):n("",!0),e.value?(r(),p(v,{key:1,"item-details":e.value},null,8,["item-details"])):n("",!0)],64))}});export{X as default};
