.filters[data-v-16cfc2f2]{padding:20px 20px 6px}.provider-description[data-v-16cfc2f2]{display:-webkit-box;-webkit-line-clamp:3;line-clamp:3;-webkit-box-orient:vertical;overflow:hidden;text-overflow:ellipsis;line-height:1.4em;max-height:4.2em}.provider-description.truncated-text[data-v-16cfc2f2]{margin-bottom:16px!important}
