.filters-container[data-v-730d2954]{display:flex;align-items:stretch;gap:12px;flex:1;flex-wrap:wrap}.search-field[data-v-730d2954]{flex:1 1 auto;min-width:250px;max-width:400px}.filter-buttons[data-v-730d2954]{display:flex;gap:8px;flex-shrink:0;flex-wrap:wrap}.filter-buttons .v-btn[data-v-730d2954]{min-width:100px}@media (max-width: 960px){.filters-container[data-v-730d2954]{flex-direction:column;align-items:stretch}.search-field[data-v-730d2954]{width:100%;min-width:100%}.filter-buttons[data-v-730d2954]{width:100%}.filter-buttons .v-btn[data-v-730d2954]{flex:1 1 auto;min-width:120px}}[data-v-730d2954] .v-list-item .v-checkbox-btn,[data-v-730d2954] .v-list-item .v-checkbox-btn .v-input__control{display:flex;align-items:center}[data-v-730d2954] .v-list-item .v-checkbox-btn .v-selection-control{min-height:auto}
